# Changelog

## 0.0.2 (2025-10-22)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/whopio/whopsdk-python/compare/v0.0.1...v0.0.2)

### Features

* **api:** api update ([2d9ebee](https://github.com/whopio/whopsdk-python/commit/2d9ebeebfa02aed3ec8b515d0e5b11de07062a38))
* **api:** api update ([5663cf4](https://github.com/whopio/whopsdk-python/commit/5663cf45944bf6f9d236b7a77aac23ce7f17fb61))
* **api:** api update ([d3d6d23](https://github.com/whopio/whopsdk-python/commit/d3d6d2364fbac6ec7e828471093c27e5bdba8527))
* **api:** api update ([f05be6f](https://github.com/whopio/whopsdk-python/commit/f05be6fd65bbd8fca4400d2e38e727153a72de43))
* **api:** api update ([cb2935f](https://github.com/whopio/whopsdk-python/commit/cb2935feaef3aa0fe324bf2bb2bb193c96b12275))
* **api:** api update ([d66c088](https://github.com/whopio/whopsdk-python/commit/d66c08873a123a5b65a5fa6f17e66ec6668e37a3))
* **api:** manual updates ([e0bea9f](https://github.com/whopio/whopsdk-python/commit/e0bea9ff169b03e85ba7111ccd7cbe1f4a1eb4cf))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([a946c15](https://github.com/whopio/whopsdk-python/commit/a946c15a8d418258f8d259714e725922e44c9389))

## 0.0.1 (2025-10-16)

Full Changelog: [v0.0.1...v0.0.1](https://github.com/whopio/whopsdk-python/compare/v0.0.1...v0.0.1)

### Features

* **api:** add pagination ([cca20a0](https://github.com/whopio/whopsdk-python/commit/cca20a093df670d6f5fe55e78c741770b774848b))
* **api:** api update ([ede5834](https://github.com/whopio/whopsdk-python/commit/ede58347affb1212ee28e9f6c0cd4ad4cbc623e3))
* **api:** api update ([dea9ff3](https://github.com/whopio/whopsdk-python/commit/dea9ff31a3eb4a13c0495b21920fe15c89d08286))
* **api:** api update ([5c15603](https://github.com/whopio/whopsdk-python/commit/5c156032a6e24944bbb86f50382589ebc6f0cfbd))
* **api:** api update ([430272f](https://github.com/whopio/whopsdk-python/commit/430272f320ab8f916f47734eeb19a8fe67ac8577))
* **api:** api update ([c647c8e](https://github.com/whopio/whopsdk-python/commit/c647c8ed07e312dcc69a9b219800ab9c311022d0))
* **api:** api update ([ce3f9b6](https://github.com/whopio/whopsdk-python/commit/ce3f9b6ed25f68f5c620fbd3f211691308df24d9))
* **api:** api update ([130334e](https://github.com/whopio/whopsdk-python/commit/130334e85ad9731a64d4ef8c7afcb5362eed6f4d))
* **api:** api update ([95569a2](https://github.com/whopio/whopsdk-python/commit/95569a2d85672edd68c0770cf029c93808ecee5c))
* **api:** api update ([1e4d054](https://github.com/whopio/whopsdk-python/commit/1e4d05465e6b1d5ce9711dd6c3cfb6ffbccec0d7))
* **api:** api update ([a4087f9](https://github.com/whopio/whopsdk-python/commit/a4087f9a788febc82df09ef1ffde3b41aa5c3eb2))
* **api:** api update ([bbc3f3e](https://github.com/whopio/whopsdk-python/commit/bbc3f3e13fd41728877da8ab37c1002a336add9c))
* **api:** api update ([2078d4d](https://github.com/whopio/whopsdk-python/commit/2078d4dd7a4bd57d35a7c236c00c1692dfa1c3e3))
* **api:** api update ([0ae44e0](https://github.com/whopio/whopsdk-python/commit/0ae44e054d52c961863d5bb964c4ac8cd4d8ccf2))
* **api:** api update ([f96a9fa](https://github.com/whopio/whopsdk-python/commit/f96a9fade2077985f3a57a564fcf5d3a2a4ee247))
* **api:** api update ([6229709](https://github.com/whopio/whopsdk-python/commit/6229709ab174b897557891d2f8b9e8d1dd4f850f))
* **api:** api update ([a05758f](https://github.com/whopio/whopsdk-python/commit/a05758f1823ea4aba6f0124816432dcb1ad854ec))
* **api:** api update ([5826789](https://github.com/whopio/whopsdk-python/commit/5826789f3441d29195e1f9a50dcc5a8dfa823bd7))
* **api:** api update ([3b5313b](https://github.com/whopio/whopsdk-python/commit/3b5313ba1ba150dbc7bd0ba09ac0e7db3871add4))
* **api:** api update ([b111425](https://github.com/whopio/whopsdk-python/commit/b111425bddc392221ae058427e04f52b50e79f6a))
* **api:** api update ([1196432](https://github.com/whopio/whopsdk-python/commit/11964327da075908f521328225ee2d9f0a5d08c4))
* **api:** api update ([224d45a](https://github.com/whopio/whopsdk-python/commit/224d45a1b17ea90876591c55c2fd48f2606412a6))
* **api:** api update ([fcf595c](https://github.com/whopio/whopsdk-python/commit/fcf595cbeda1c35d183aa4b190d5b03f59d1af13))
* **api:** api update ([b15bf19](https://github.com/whopio/whopsdk-python/commit/b15bf195a340cc5dc94ed40eea9077c26705e91b))
* **api:** api update ([082a644](https://github.com/whopio/whopsdk-python/commit/082a644a872f6363f2e4f2065c66cb8530010815))
* **api:** api update ([2317b5a](https://github.com/whopio/whopsdk-python/commit/2317b5a5dfd31494dde3c654ee516438111d6e5d))
* **api:** api update ([bf60366](https://github.com/whopio/whopsdk-python/commit/bf60366c5dd32d0ea75c1b1e19a0c3fde03766fd))
* **api:** api update ([decb5db](https://github.com/whopio/whopsdk-python/commit/decb5dbf980d39c1b22294b931f51cddb7471669))
* **api:** api update ([7873742](https://github.com/whopio/whopsdk-python/commit/78737422c7dbb74d5de60570ce1c0beb9b5133d5))
* **api:** api update ([9dd4b20](https://github.com/whopio/whopsdk-python/commit/9dd4b209ba2faf9f0672b82408c41a05957778ae))
* **api:** api update ([2586ba0](https://github.com/whopio/whopsdk-python/commit/2586ba01139d748b91b6568a5b1646d291b058d4))
* **api:** api update ([c5c046d](https://github.com/whopio/whopsdk-python/commit/c5c046de999a35015cabec8d359dc8eb9d7e7cef))
* **api:** api update ([afbfc7c](https://github.com/whopio/whopsdk-python/commit/afbfc7cda33ececc5d32a68b61eb1bdce25d440d))
* **api:** api update ([684a4d2](https://github.com/whopio/whopsdk-python/commit/684a4d29083abea1924abe1d476566cea4836229))
* **api:** api update ([5eb68c8](https://github.com/whopio/whopsdk-python/commit/5eb68c8b5e834cb5d41b4ef6d92239180552068f))
* **api:** api update ([2777c1e](https://github.com/whopio/whopsdk-python/commit/2777c1ee8fa2b7568a5f7aa3ed7f6214e73e151e))
* **api:** api update ([522da9e](https://github.com/whopio/whopsdk-python/commit/522da9e0d26dddf66515450f89d6c3cd07728ec4))
* **api:** api update ([310859a](https://github.com/whopio/whopsdk-python/commit/310859a9111d682694c3c0f9146aebe90b8738f6))
* **api:** api update ([f8c7f12](https://github.com/whopio/whopsdk-python/commit/f8c7f1231bf24f1e6ee8217a604b7f7a26369e42))
* **api:** api update ([14d6686](https://github.com/whopio/whopsdk-python/commit/14d6686006244af27c8484222bfee7ca7797946a))
* **api:** api update ([e8ad1b6](https://github.com/whopio/whopsdk-python/commit/e8ad1b65c379c83598ab5e3df4323375effb2013))
* **api:** api update ([f0ddc58](https://github.com/whopio/whopsdk-python/commit/f0ddc5848b1123a311901c2f18dae20a8f111b3e))
* **api:** manual update ([6616062](https://github.com/whopio/whopsdk-python/commit/661606245f75b1e051eb8261eb25e3f0a9ba7530))
* **api:** manual updates ([8bd5020](https://github.com/whopio/whopsdk-python/commit/8bd5020184f7188182bd6bbefed5b57612576c0d))
* **api:** manual updates ([7f0eeb0](https://github.com/whopio/whopsdk-python/commit/7f0eeb0660a892ad93cf0100f3a54a4883462490))
* **api:** manual updates ([19708a9](https://github.com/whopio/whopsdk-python/commit/19708a9b9f9bff55b176f792f7c0a42254879e61))
* **api:** manual updates ([5922b82](https://github.com/whopio/whopsdk-python/commit/5922b825b2124d45f4497fe87c49b3ab9e956bc4))
* **api:** manual updates ([a4cfb11](https://github.com/whopio/whopsdk-python/commit/a4cfb111221fa2cf876c16f6fcef29ed85aca703))
* **api:** manual updates ([4934302](https://github.com/whopio/whopsdk-python/commit/4934302bdc2aeecfeadc29f8bb7f0b781e359998))
* **api:** manual updates ([12a0566](https://github.com/whopio/whopsdk-python/commit/12a0566c02d13586c06f332ed00432cb217add25))
* **api:** manual updates ([b00456a](https://github.com/whopio/whopsdk-python/commit/b00456a6975957c8cea04347b64a5193f4ab1677))
* **api:** manual updates ([a8033bc](https://github.com/whopio/whopsdk-python/commit/a8033bcbc16920240576131cf1da1915ba9d02fd))
* **api:** manual updates ([063fdca](https://github.com/whopio/whopsdk-python/commit/063fdcae5471d877d2f61dd375a9d9864ca2c4c6))
* **api:** manual updates ([1f249fc](https://github.com/whopio/whopsdk-python/commit/1f249fcad56842b606efba8ee9a9fd2cfb3a5209))
* **api:** manual updates ([a4a0aa7](https://github.com/whopio/whopsdk-python/commit/a4a0aa722072b80194fd11eb3b8008816eb7b618))
* **api:** manual updates ([cf6f5db](https://github.com/whopio/whopsdk-python/commit/cf6f5db50900489042ceba730baf9ebd326457b6))
* **api:** manual updates ([62f7869](https://github.com/whopio/whopsdk-python/commit/62f7869124a4b80b6973601ded3499b30d3ada62))
* **api:** manual updates ([5d81435](https://github.com/whopio/whopsdk-python/commit/5d8143583c4a800e1e83d053c6729ea803adb609))
* **api:** manual updates ([606b0f0](https://github.com/whopio/whopsdk-python/commit/606b0f05c079260b7ae12264ae0059198ac7afc9))
* **api:** manual updates ([455802f](https://github.com/whopio/whopsdk-python/commit/455802f91d272be82d13cfcd3c1d92db043c7c70))
* **api:** manual updates ([821148f](https://github.com/whopio/whopsdk-python/commit/821148f771ab4f068497d781ea42034c083667e0))
* **api:** manual updates ([724a475](https://github.com/whopio/whopsdk-python/commit/724a475899b0c22f5b5f500f12b0df2e87526b83))
* **api:** manual updates ([96fd8b2](https://github.com/whopio/whopsdk-python/commit/96fd8b255e581c67c56c6f6a39f684fc8be3ed7d))
* **api:** manual updates ([6d14145](https://github.com/whopio/whopsdk-python/commit/6d14145b53350ed0d53d622d6288673331e951f1))
* **api:** manual updates ([327a856](https://github.com/whopio/whopsdk-python/commit/327a8565176ce86b1af0c679d9db5499deea6e88))
* **api:** manual updates ([72ab133](https://github.com/whopio/whopsdk-python/commit/72ab133134a390ae5395e07ebf1459df666d859e))


### Chores

* configure new SDK language ([ebf6304](https://github.com/whopio/whopsdk-python/commit/ebf63045bd54a7988c1f0b2867224b7003f3fdef))
* **internal:** detect missing future annotations with ruff ([6e080b8](https://github.com/whopio/whopsdk-python/commit/6e080b854f8e403bddee5077d6891ae53a99ac08))
* update SDK settings ([c9b0496](https://github.com/whopio/whopsdk-python/commit/c9b049612845640f2637e2139a4e6a5e61b960d8))
* update SDK settings ([fc59c60](https://github.com/whopio/whopsdk-python/commit/fc59c6018a3ff8c9e1a667ece0021676062fbed3))
